@@ -22,7 +22,7 @@
 #ifndef PROCESSMODEL_P_H_
 #define PROCESSMODEL_P_H_
 
-#include <processcore/process.h>
+#include <processcore/extended_process_list.h>
 #include "ProcessModel.h"
 
 #include <kuser.h>
@@ -182,7 +182,7 @@ class ProcessModelPrivate : public QObject
         long long mMemTotal; ///< the total amount of physical memory in kb in the machine.  We can used this to determine the percentage of memory an app is using
         int mNumProcessorCores;  ///< The number of (enabled) processor cores in the this machine
 
-        KSysGuard::Processes *mProcesses;  ///< The processes instance
+        KSysGuard::ExtendedProcesses *mProcesses;  ///< The processes instance
 
         QPixmap mBlankPixmap; ///< Used to pad out process names which don't have an icon
 
@@ -208,6 +208,8 @@ class ProcessModelPrivate : public QObject
         /** Storage for the history entries. We need one per percentage column. */
         QHash<KSysGuard::Process *, QVector<ProcessModel::PercentageHistoryEntry>> mMapProcessCPUHistory;
 
+        QVector<KSysGuard::ProcessAttribute*> mExtraAttributes;
+
 #ifdef HAVE_XRES
         bool mHaveXRes; ///< True if the XRes extension is available at run time
         QMap<qlonglong, XID> mXResClientResources;
